@@ -88,8 +88,11 @@ def login(click_context, core_seeds, username, password):
     if has_errors:
         click.secho('WARNING: At least one core service could not be reached. Check your username/password and endpoint IPs.', bold=True, fg='yellow')
 
-    with open(ctx.config_file) as fd:
-        data = yaml.safe_load(fd)
+    try:
+        with open(ctx.config_file) as fd:
+            data = yaml.safe_load(fd)
+    except FileNotFoundError:
+        data = {}
 
     click.confirm('Save credentials for cluster {cluster} at {fn} in plaintext?'.format(cluster=ctx.cluster, fn=ctx.config_file), abort=True)
 
